/**
 * Copyright (c) 2014 Zeligsoft (2009) Limited  and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package org.eclipse.papyrus.qompass.modellibs.core.xtend;

import com.google.common.base.Objects;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.eclipse.papyrus.qompass.modellibs.core.xtend.UMLAction;
import org.eclipse.uml2.uml.Behavior;
import org.eclipse.uml2.uml.Transition;
import org.eclipse.xtend.lib.annotations.Accessors;
import org.eclipse.xtext.xbase.lib.CollectionLiterals;
import org.eclipse.xtext.xbase.lib.Conversions;
import org.eclipse.xtext.xbase.lib.Pure;

/**
 * A chain of state entry, exit and transition actions for a "flat"
 * {@link Transition}.
 * 
 * @author eposse
 */
@SuppressWarnings("all")
public class UMLChain {
  @Accessors
  private List<UMLAction> actions;
  
  @Accessors
  private Transition owner;
  
  private static Map<Transition, UMLChain> chains;
  
  public UMLChain() {
    ArrayList<UMLAction> _newArrayList = CollectionLiterals.<UMLAction>newArrayList();
    this.actions = _newArrayList;
  }
  
  public UMLChain(final List<UMLAction> actions) {
    ArrayList<UMLAction> _newArrayList = CollectionLiterals.<UMLAction>newArrayList(((UMLAction[])Conversions.unwrapArray(actions, UMLAction.class)));
    this.actions = _newArrayList;
  }
  
  public static void initChains() {
    HashMap<Transition, UMLChain> _hashMap = new HashMap<Transition, UMLChain>();
    UMLChain.chains = _hashMap;
  }
  
  /**
   * Return the chain of behaviors associated with a transition
   * IF the chain does not exist yet, it will be created (and stored in a hash map)
   * @param t
   * @return
   */
  public static UMLChain chain(final Transition t) {
    UMLChain chain = UMLChain.chains.get(t);
    boolean _equals = Objects.equal(chain, null);
    if (_equals) {
      UMLChain _uMLChain = new UMLChain();
      chain = _uMLChain;
      chain.setOwner(t);
      UMLChain.chains.put(t, chain);
    }
    return chain;
  }
  
  public UMLChain append(final UMLAction action) {
    this.actions.add(action);
    return this;
  }
  
  public UMLChain append(final Behavior behavior) {
    boolean _notEquals = (!Objects.equal(behavior, null));
    if (_notEquals) {
      UMLAction _uMLAction = new UMLAction(behavior);
      this.append(_uMLAction);
    }
    return this;
  }
  
  public UMLChain prepend(final UMLAction action) {
    this.actions.add(0, action);
    return this;
  }
  
  public UMLChain prepend(final Behavior behavior) {
    UMLAction _uMLAction = new UMLAction(behavior);
    this.prepend(_uMLAction);
    return this;
  }
  
  public Transition getOwner() {
    return this.owner;
  }
  
  public UMLChain setOwner(final Transition t) {
    UMLChain _xblockexpression = null;
    {
      this.owner = t;
      Behavior _effect = t.getEffect();
      _xblockexpression = this.append(_effect);
    }
    return _xblockexpression;
  }
  
  @Pure
  public List<UMLAction> getActions() {
    return this.actions;
  }
  
  public void setActions(final List<UMLAction> actions) {
    this.actions = actions;
  }
}
